#
# spec file for package ghc-scientific
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name scientific
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.3.5.1
Release:        8.1
Summary:        Numbers represented using scientific notation
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-integer-logarithms-devel
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-smallcheck-devel
BuildRequires:  ghc-tasty-ant-xml-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-smallcheck-devel
%endif

%description
'Data.Scientific' provides the number type 'Scientific'. Scientific numbers are
arbitrary precision and space efficient. They are represented using
<http://en.wikipedia.org/wiki/Scientific_notation scientific notation>.
The implementation uses a coefficient 'c :: 'Integer'' and a base-10 exponent
'e :: 'Int''. A scientific number corresponds to the 'Fractional' number:
''fromInteger' c * 10 '^^' e'.

Note that since we're using an 'Int' to represent the exponent these numbers
aren't truly arbitrary precision. I intend to change the type of the exponent
to 'Integer' in a future release.

The main application of 'Scientific' is to be used as the target of parsing
arbitrary precision numbers coming from an untrusted source. The advantages
over using 'Rational' for this are that:

* A 'Scientific' is more efficient to construct. Rational numbers need to be
constructed using '%' which has to compute the 'gcd' of the 'numerator' and
'denominator'.

* 'Scientific' is safe against numbers with huge exponents. For example:
'1e1000000000 :: 'Rational'' will fill up all space and crash your program.
Scientific works as expected:

> > read "1e1000000000" :: Scientific > 1.0e1000000000

* Also, the space usage of converting scientific numbers with huge exponents to
''Integral's' (like: 'Int') or ''RealFloat's' (like: 'Double' or 'Float') will
always be bounded by the target type.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc changelog

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Tue Jul 11 2017 psimons@suse.com
- Update to version 0.3.5.1.
* Mon Jul  3 2017 psimons@suse.com
- Update to version 0.3.4.15 revision 2.
* Mon Jun 12 2017 psimons@suse.com
- Update to version 0.3.4.15.
* Wed May 31 2017 psimons@suse.com
- Update to version 0.3.4.13.
* Wed Apr 19 2017 psimons@suse.com
- Update to version 0.3.4.12 with cabal2obs.
* Tue Apr  4 2017 psimons@suse.com
- Update to version 0.3.4.11 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 0.3.4.10 with cabal2obs.
* Wed Jan  4 2017 psimons@suse.com
- Update to version 0.3.4.9 revision 1 with cabal2obs.
* Fri Jul 22 2016 psimons@suse.com
- Update to version 0.3.4.9 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.3.4.8 revision 0 with cabal2obs.
* Sun Jul  3 2016 mimi.vx@gmail.com
- update to 0.3.4.8
  * Make bytestring-builder's installation conditional based on a Cabal flag.
* Fri Jul  1 2016 toddrme2178@gmail.com
- Make Group tag consistent with other GHC packages.
* Sun Jun 12 2016 mimi.vx@gmail.com
- update to 0.3.4.7
  * Unconditionally export Data.ByteString.Builder.Scientific.
  * The bytestring-builder cabal flag has been removed.
  * Depend on bytestring-builder for backwards compatibility for GHC < 7.8.
* Sat Mar 12 2016 mimi.vx@gmail.com
- update to 0.3.4.6
  * Made toDecimalDigits more similar to floatToDigits
  * Introduce a special case for 0 in fromFloatDigits
* Thu Mar 10 2016 mimi.vx@gmail.com
- update to 0.3.4.5
  * Support GHC-8.0.1
  * Support binary-0.8
* Sun Nov 29 2015 mimi.vx@gmail.com
- update to 0.3.4.4
  * Fix build with integer-simple.
  * Improved performance of toDecimalDigits by 13%%.
* Mon Oct 12 2015 mimi.vx@gmail.com
- update to 0.3.4.2
  * build fixes
* Sun Oct  4 2015 mimi.vx@gmail.com
- update to 0.3.4.0
  * Added fromRationalRepetend & toRationalRepetend
  for safely converting from and to rationals
  which have a repeating decimal representation like:
  1 %% 28 = 0.03(571428).
  * Added a Binary instance.
  * Various performance improvements.
  * Support vector-0.11
  * Support tasty-0.11
  * Support criterion-1.1.0.0
* Sun Apr 12 2015 mimi.vx@gmail.com
- update to 0.3.3.8
* Sun Mar 29 2015 mpluskal@suse.com
- Remove ExclusiveArch
* Mon Feb  2 2015 mpluskal@suse.com
-  Initial package
